package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.OrhonFgqy;

/**
 * 非公企业信息Service接口
 *
 * @author ruoyi
 * @date 2020-07-16
 */
public interface IOrhonFgqyService
{
    /**
     * 查询非公企业信息
     *
     * @param id 非公企业信息ID
     * @return 非公企业信息
     */
    public com.ruoyi.system.domain.OrhonFgqy selectOrhonFgqyById(String id);

    /**
     * 查询非公企业信息列表
     *
     * @param orhonFgqy 非公企业信息
     * @return 非公企业信息集合
     */
    public java.util.List<com.ruoyi.system.domain.OrhonFgqy> selectOrhonFgqyList(com.ruoyi.system.domain.OrhonFgqy orhonFgqy);

    /**
     * 新增非公企业信息
     *
     * @param orhonFgqy 非公企业信息
     * @return 结果
     */
    public int insertOrhonFgqy(com.ruoyi.system.domain.OrhonFgqy orhonFgqy);

    /**
     * 修改非公企业信息
     *
     * @param orhonFgqy 非公企业信息
     * @return 结果
     */
    public int updateOrhonFgqy(com.ruoyi.system.domain.OrhonFgqy orhonFgqy);

    /**
     * 批量删除非公企业信息
     *
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteOrhonFgqyByIds(String ids);

    /**
     * 删除非公企业信息信息
     *
     * @param id 非公企业信息ID
     * @return 结果
     */
    public int deleteOrhonFgqyById(String id);

    public String findQyzs();

    public String findDzz();
}
